/**
 * DevExtreme (cjs/renovation/utils/plugin/context.js)
 * Version: 22.1.0 (build 21357-0315)
 * Build date: Thu Dec 23 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.PluginsContext = exports.Plugins = exports.PluginGetter = exports.PluginEntity = void 0;
exports.createGetter = createGetter;
exports.createPlaceholder = createPlaceholder;
exports.createValue = createValue;
var _inferno = require("@devextreme/runtime/inferno");

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var nextEntityId = 1;
var PluginEntity = function() {
    function PluginEntity() {
        this.id = nextEntityId;
        nextEntityId += 1
    }
    var _proto = PluginEntity.prototype;
    _proto.getValue = function(value) {
        return value
    };
    return PluginEntity
}();
exports.PluginEntity = PluginEntity;
var PluginGetter = function(_PluginEntity) {
    _inheritsLoose(PluginGetter, _PluginEntity);

    function PluginGetter(defaultValue) {
        var _this;
        _this = _PluginEntity.call(this) || this;
        _this.defaultValue = defaultValue;
        return _this
    }
    var _proto2 = PluginGetter.prototype;
    _proto2.getValue = function(value) {
        return value.reduce((function(base, item) {
            return item.func(base)
        }), this.defaultValue)
    };
    return PluginGetter
}(PluginEntity);
exports.PluginGetter = PluginGetter;

function createValue() {
    return new PluginEntity
}

function createGetter(defaultValue) {
    return new PluginGetter(defaultValue)
}

function createPlaceholder() {
    return new PluginEntity
}
var Plugins = function() {
    function Plugins() {
        this.items = {};
        this.subscriptions = {}
    }
    var _proto3 = Plugins.prototype;
    _proto3.set = function(entity, value) {
        this.items[entity.id] = value;
        var subscriptions = this.subscriptions[entity.id];
        if (subscriptions) {
            var callbackValue = entity.getValue(value);
            subscriptions.forEach((function(handler) {
                handler(callbackValue)
            }))
        }
    };
    _proto3.extend = function(entity, order, func) {
        var _this2 = this;
        var value = this.items[entity.id] || [];
        var insertIndex = value.filter((function(item) {
            return item.order < order
        })).length;
        var item = {
            order: order,
            func: func
        };
        value.splice(insertIndex, 0, item);
        this.set(entity, value);
        return function() {
            var index = value.indexOf(item);
            if (index >= 0) {
                value.splice(index, 1);
                _this2.set(entity, value)
            }
        }
    };
    _proto3.extendPlaceholder = function(entity, order, component) {
        var _this3 = this;
        var value = this.items[entity.id] || [];
        var insertIndex = value.filter((function(item) {
            return item.order < order
        })).length;
        var item = {
            order: order,
            component: component
        };
        value.splice(insertIndex, 0, item);
        this.set(entity, value);
        return function() {
            var index = value.indexOf(item);
            if (index >= 0) {
                value.splice(index, 1);
                _this3.set(entity, value)
            }
        }
    };
    _proto3.getValue = function(entity) {
        var value = this.items[entity.id];
        return entity.getValue(value)
    };
    _proto3.watch = function(entity, callback) {
        var value = this.items[entity.id];
        var subscriptions = this.subscriptions[entity.id] || [];
        this.subscriptions[entity.id] = subscriptions;
        if (void 0 !== value) {
            var callbackValue = entity.getValue(value);
            callback(callbackValue)
        }
        subscriptions.push(callback);
        return function() {
            var index = subscriptions.indexOf(callback);
            if (index >= 0) {
                subscriptions.splice(index, 1)
            }
        }
    };
    return Plugins
}();
exports.Plugins = Plugins;
var PluginsContext = (0, _inferno.createContext)(null);
exports.PluginsContext = PluginsContext;
