/**
 * DevExtreme (esm/exporter/jspdf/v3/rows_splitting.js)
 * Version: 22.1.0 (build 21357-0315)
 * Build date: Thu Dec 23 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import {
    isDefined
} from "../../../core/utils/type";

function splitRectsByPages(rects, topLeft, maxBottomRight) {
    if (!isDefined(rects) || 0 === rects.length) {
        return [
            []
        ]
    }
    var rectsByPage = splitRectsHorizontalByPages(rects, topLeft, maxBottomRight);
    return rectsByPage
}

function splitRectsHorizontalByPages(rects, topLeft, maxBottomRight) {
    var pages = [];
    var rectsToSplit = [...rects];
    var _loop = function() {
        var currentPageMaxRectRight = 0;
        var currentPageRects = rectsToSplit.filter(rect => {
            var currentRectRight = Math.round(1e3 * (rect.x + rect.w)) / 1e3;
            if (currentRectRight <= maxBottomRight.x) {
                if (currentPageMaxRectRight <= currentRectRight) {
                    currentPageMaxRectRight = currentRectRight
                }
                return true
            } else {
                return false
            }
        });
        currentPageRects.forEach(rect => {
            var index = rectsToSplit.indexOf(rect);
            if (-1 !== index) {
                rectsToSplit.splice(index, 1)
            }
        });
        rectsToSplit.forEach(rect => {
            rect.x = void 0 !== currentPageMaxRectRight ? rect.x - currentPageMaxRectRight + topLeft.x : rect.x
        });
        if (currentPageRects.length > 0) {
            pages.push(currentPageRects)
        } else {
            pages.push(rectsToSplit);
            return "break"
        }
    };
    while (rectsToSplit.length > 0) {
        var _ret = _loop();
        if ("break" === _ret) {
            break
        }
    }
    return pages
}
export {
    splitRectsByPages
};
