/**
 * DevExtreme (esm/renovation/ui/grids/data_grid_light/widgets/pager.js)
 * Version: 22.1.0 (build 21357-0315)
 * Build date: Thu Dec 23 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["allowedPageSizes", "displayMode", "infoText", "showInfo", "showNavigationButtons", "showPageSizeSelector", "visible"];
import {
    createComponentVNode
} from "inferno";
import {
    InfernoEffect,
    InfernoComponent
} from "@devextreme/runtime/inferno";
import {
    PlaceholderExtender
} from "../../../../utils/plugin/placeholder_extender";
import messageLocalization from "../../../../../localization/message";
import {
    PagerContent
} from "../../../pager/content";
import {
    PagingPlugin
} from "./paging";
import {
    FooterPlaceholder
} from "../views/footer";
import {
    PluginsContext
} from "../../../../utils/plugin/context";
var DATAGRID_PAGER_CLASS = "dx-datagrid-pager";
export var viewFunction = viewModel => createComponentVNode(2, PlaceholderExtender, {
    type: FooterPlaceholder,
    order: 1,
    template: () => createComponentVNode(2, PagerContent, {
        className: DATAGRID_PAGER_CLASS,
        pageSizes: viewModel.allowedPageSizes,
        displayMode: viewModel.props.displayMode,
        infoText: viewModel.props.infoText,
        showInfo: viewModel.props.showInfo,
        showNavigationButtons: viewModel.props.showNavigationButtons,
        showPageSizes: viewModel.props.showPageSizeSelector,
        pageCount: viewModel.pageCount,
        visible: viewModel.props.visible,
        totalCount: viewModel.totalCount,
        pageIndex: viewModel.pageIndex,
        pageIndexChange: viewModel.onPageIndexChange,
        pageSize: "all" === viewModel.pageSize ? 0 : viewModel.pageSize,
        pageSizeChange: viewModel.onPageSizeChange
    })
});
export var PagerProps = {
    allowedPageSizes: "auto",
    displayMode: "adaptive",
    get infoText() {
        return messageLocalization.format("dxPager-infoText")
    },
    showInfo: false,
    showNavigationButtons: false,
    showPageSizeSelector: false,
    visible: true
};
export class Pager extends InfernoComponent {
    constructor(props) {
        super(props);
        this.__getterCache = {};
        this.state = {
            pageIndex: 0,
            pageSize: 0,
            totalCount: 0,
            pageCount: 0
        };
        this.subscribeToPagingPluginUpdates = this.subscribeToPagingPluginUpdates.bind(this);
        this.onPageSizeChange = this.onPageSizeChange.bind(this);
        this.onPageIndexChange = this.onPageIndexChange.bind(this)
    }
    get plugins() {
        if ("PluginsContext" in this.context) {
            return this.context.PluginsContext
        }
        return PluginsContext
    }
    createEffects() {
        return [new InfernoEffect(this.subscribeToPagingPluginUpdates, [this.plugins])]
    }
    updateEffects() {
        var _this$_effects$;
        null === (_this$_effects$ = this._effects[0]) || void 0 === _this$_effects$ ? void 0 : _this$_effects$.update([this.plugins])
    }
    subscribeToPagingPluginUpdates() {
        this.plugins.watch(PagingPlugin, prop => {
            this.setState(__state_argument => ({
                pageIndex: prop.pageIndex
            }));
            this.setState(__state_argument => ({
                pageSize: prop.pageSize
            }));
            this.setState(__state_argument => ({
                totalCount: prop.totalCount
            }));
            this.setState(__state_argument => ({
                pageCount: prop.pageCount
            }))
        })
    }
    onPageSizeChange(pageSize) {
        var _this$plugins$getValu;
        var setPageSize = null === (_this$plugins$getValu = this.plugins.getValue(PagingPlugin)) || void 0 === _this$plugins$getValu ? void 0 : _this$plugins$getValu.setPageSize;
        if (!setPageSize) {
            return
        }
        if (0 === pageSize) {
            setPageSize("all")
        } else {
            setPageSize(pageSize)
        }
    }
    onPageIndexChange(pageIndex) {
        var _this$plugins$getValu2, _this$plugins$getValu3;
        null === (_this$plugins$getValu2 = this.plugins.getValue(PagingPlugin)) || void 0 === _this$plugins$getValu2 ? void 0 : null === (_this$plugins$getValu3 = _this$plugins$getValu2.setPageIndex) || void 0 === _this$plugins$getValu3 ? void 0 : _this$plugins$getValu3.call(_this$plugins$getValu2, pageIndex)
    }
    get allowedPageSizes() {
        if (void 0 !== this.__getterCache.allowedPageSizes) {
            return this.__getterCache.allowedPageSizes
        }
        return this.__getterCache.allowedPageSizes = (() => {
            var pageSize = this.state.pageSize;
            if ("auto" === this.props.allowedPageSizes) {
                if ("all" === pageSize) {
                    return []
                }
                return [Math.floor(pageSize / 2), pageSize, 2 * pageSize]
            }
            return this.props.allowedPageSizes
        })()
    }
    get restAttributes() {
        var _this$props = this.props,
            restProps = _objectWithoutPropertiesLoose(_this$props, _excluded);
        return restProps
    }
    componentWillUpdate(nextProps, nextState, context) {
        super.componentWillUpdate();
        if (this.state.pageSize !== nextState.pageSize || this.props.allowedPageSizes !== nextProps.allowedPageSizes) {
            this.__getterCache.allowedPageSizes = void 0
        }
    }
    render() {
        var props = this.props;
        return viewFunction({
            props: _extends({}, props),
            pageIndex: this.state.pageIndex,
            pageSize: this.state.pageSize,
            totalCount: this.state.totalCount,
            pageCount: this.state.pageCount,
            plugins: this.plugins,
            onPageSizeChange: this.onPageSizeChange,
            onPageIndexChange: this.onPageIndexChange,
            allowedPageSizes: this.allowedPageSizes,
            restAttributes: this.restAttributes
        })
    }
}
Pager.defaultProps = PagerProps;
