/**
 * DevExtreme (esm/renovation/ui/grids/data_grid_light/widgets/paging.js)
 * Version: 22.1.0 (build 21357-0315)
 * Build date: Thu Dec 23 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["defaultPageIndex", "defaultPageSize", "enabled", "pageIndex", "pageIndexChange", "pageSize", "pageSizeChange"];
import {
    createFragment
} from "inferno";
import {
    InfernoEffect,
    InfernoComponent
} from "@devextreme/runtime/inferno";
import {
    PluginsContext,
    createValue
} from "../../../../utils/plugin/context";
import {
    VisibleItems
} from "../data_grid_light";
export var viewFunction = () => createFragment();
export var PagingProps = {
    enabled: true,
    defaultPageSize: 20,
    pageSizeChange: () => {},
    defaultPageIndex: 0,
    pageIndexChange: () => {}
};
export var PagingPlugin = createValue();
export class Paging extends InfernoComponent {
    constructor(props) {
        super(props);
        this.state = {
            dataSource: [],
            pageSize: void 0 !== this.props.pageSize ? this.props.pageSize : this.props.defaultPageSize,
            pageIndex: void 0 !== this.props.pageIndex ? this.props.pageIndex : this.props.defaultPageIndex
        };
        this.addPagingHandler = this.addPagingHandler.bind(this);
        this.updatePagingProps = this.updatePagingProps.bind(this);
        this.setPageIndex = this.setPageIndex.bind(this);
        this.setPageSize = this.setPageSize.bind(this);
        this.calculateVisibleItems = this.calculateVisibleItems.bind(this)
    }
    get plugins() {
        if ("PluginsContext" in this.context) {
            return this.context.PluginsContext
        }
        return PluginsContext
    }
    createEffects() {
        return [new InfernoEffect(this.addPagingHandler, [this.plugins, this.props.enabled, this.state.pageSize, this.props.pageSize, this.state.pageIndex, this.props.pageIndex]), new InfernoEffect(this.updatePagingProps, [this.plugins, this.state.pageIndex, this.props.pageIndex, this.props.pageIndexChange, this.state.pageSize, this.props.pageSize, this.props.pageSizeChange, this.state.dataSource])]
    }
    updateEffects() {
        var _this$_effects$, _this$_effects$2;
        null === (_this$_effects$ = this._effects[0]) || void 0 === _this$_effects$ ? void 0 : _this$_effects$.update([this.plugins, this.props.enabled, this.state.pageSize, this.props.pageSize, this.state.pageIndex, this.props.pageIndex]);
        null === (_this$_effects$2 = this._effects[1]) || void 0 === _this$_effects$2 ? void 0 : _this$_effects$2.update([this.plugins, this.state.pageIndex, this.props.pageIndex, this.props.pageIndexChange, this.state.pageSize, this.props.pageSize, this.props.pageSizeChange, this.state.dataSource])
    }
    addPagingHandler() {
        return this.plugins.extend(VisibleItems, 1, items => {
            this.setState(__state_argument => ({
                dataSource: items
            }));
            return this.calculateVisibleItems(items)
        })
    }
    updatePagingProps() {
        this.plugins.set(PagingPlugin, {
            pageIndex: void 0 !== this.props.pageIndex ? this.props.pageIndex : this.state.pageIndex,
            setPageIndex: this.setPageIndex,
            pageSize: this.pageSize,
            setPageSize: this.setPageSize,
            totalCount: this.totalCount,
            pageCount: this.pageCount
        })
    }
    setPageIndex(pageIndex) {
        var __newValue;
        this.setState(__state_argument => {
            __newValue = pageIndex;
            return {
                pageIndex: __newValue
            }
        });
        this.props.pageIndexChange(__newValue)
    }
    setPageSize(pageSize) {
        var __newValue;
        this.setState(__state_argument => {
            __newValue = pageSize;
            return {
                pageSize: __newValue
            }
        });
        this.props.pageSizeChange(__newValue)
    }
    calculateVisibleItems(dataSource) {
        if (!this.props.enabled || "all" === this.pageSize) {
            return dataSource
        }
        var start = (void 0 !== this.props.pageIndex ? this.props.pageIndex : this.state.pageIndex) * this.pageSize;
        var end = start + this.pageSize;
        return dataSource.slice(start, end)
    }
    get totalCount() {
        return this.state.dataSource.length
    }
    get pageCount() {
        if ("all" === this.pageSize) {
            return 1
        }
        return Math.ceil(this.totalCount / this.pageSize)
    }
    get pageSize() {
        if (0 === (void 0 !== this.props.pageSize ? this.props.pageSize : this.state.pageSize)) {
            return "all"
        }
        return void 0 !== this.props.pageSize ? this.props.pageSize : this.state.pageSize
    }
    get restAttributes() {
        var _this$props$pageSize$ = _extends({}, this.props, {
                pageSize: void 0 !== this.props.pageSize ? this.props.pageSize : this.state.pageSize,
                pageIndex: void 0 !== this.props.pageIndex ? this.props.pageIndex : this.state.pageIndex
            }),
            restProps = _objectWithoutPropertiesLoose(_this$props$pageSize$, _excluded);
        return restProps
    }
    render() {
        this.props;
        return viewFunction()
    }
}
Paging.defaultProps = PagingProps;
