/**
 * DevExtreme (esm/renovation/utils/plugin/context.js)
 * Version: 22.1.0 (build 21357-0315)
 * Build date: Thu Dec 23 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import {
    createContext
} from "@devextreme/runtime/inferno";
var nextEntityId = 1;
export class PluginEntity {
    constructor() {
        this.id = nextEntityId;
        nextEntityId += 1
    }
    getValue(value) {
        return value
    }
}
export class PluginGetter extends PluginEntity {
    constructor(defaultValue) {
        super();
        this.defaultValue = defaultValue
    }
    getValue(value) {
        return value.reduce((base, item) => item.func(base), this.defaultValue)
    }
}
export function createValue() {
    return new PluginEntity
}
export function createGetter(defaultValue) {
    return new PluginGetter(defaultValue)
}
export function createPlaceholder() {
    return new PluginEntity
}
export class Plugins {
    constructor() {
        this.items = {};
        this.subscriptions = {}
    }
    set(entity, value) {
        this.items[entity.id] = value;
        var subscriptions = this.subscriptions[entity.id];
        if (subscriptions) {
            var callbackValue = entity.getValue(value);
            subscriptions.forEach(handler => {
                handler(callbackValue)
            })
        }
    }
    extend(entity, order, func) {
        var value = this.items[entity.id] || [];
        var insertIndex = value.filter(item => item.order < order).length;
        var item = {
            order: order,
            func: func
        };
        value.splice(insertIndex, 0, item);
        this.set(entity, value);
        return () => {
            var index = value.indexOf(item);
            if (index >= 0) {
                value.splice(index, 1);
                this.set(entity, value)
            }
        }
    }
    extendPlaceholder(entity, order, component) {
        var value = this.items[entity.id] || [];
        var insertIndex = value.filter(item => item.order < order).length;
        var item = {
            order: order,
            component: component
        };
        value.splice(insertIndex, 0, item);
        this.set(entity, value);
        return () => {
            var index = value.indexOf(item);
            if (index >= 0) {
                value.splice(index, 1);
                this.set(entity, value)
            }
        }
    }
    getValue(entity) {
        var value = this.items[entity.id];
        return entity.getValue(value)
    }
    watch(entity, callback) {
        var value = this.items[entity.id];
        var subscriptions = this.subscriptions[entity.id] || [];
        this.subscriptions[entity.id] = subscriptions;
        if (void 0 !== value) {
            var callbackValue = entity.getValue(value);
            callback(callbackValue)
        }
        subscriptions.push(callback);
        return () => {
            var index = subscriptions.indexOf(callback);
            if (index >= 0) {
                subscriptions.splice(index, 1)
            }
        }
    }
}
export var PluginsContext = createContext(null);
