/**
 * DevExtreme (renovation/ui/grids/data_grid_light/widgets/pager.js)
 * Version: 22.1.0 (build 21357-0315)
 * Build date: Thu Dec 23 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.viewFunction = exports.PagerProps = exports.Pager = void 0;
var _inferno = require("inferno");
var _inferno2 = require("@devextreme/runtime/inferno");
var _placeholder_extender = require("../../../../utils/plugin/placeholder_extender");
var _message = _interopRequireDefault(require("../../../../../localization/message"));
var _content = require("../../../pager/content");
var _paging = require("./paging");
var _footer = require("../views/footer");
var _context = require("../../../../utils/plugin/context");
var _excluded = ["allowedPageSizes", "displayMode", "infoText", "showInfo", "showNavigationButtons", "showPageSizeSelector", "visible"];

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _objectWithoutProperties(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for (i = 0; i < sourceSymbolKeys.length; i++) {
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) {
                continue
            }
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) {
                continue
            }
            target[key] = source[key]
        }
    }
    return target
}

function _objectWithoutPropertiesLoose(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;
    for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) {
            continue
        }
        target[key] = source[key]
    }
    return target
}

function _extends() {
    _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    Object.defineProperty(Constructor, "prototype", {
        writable: false
    });
    return Constructor
}

function _assertThisInitialized(self) {
    if (void 0 === self) {
        throw new ReferenceError("this hasn't been initialised - super() hasn't been called")
    }
    return self
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var DATAGRID_PAGER_CLASS = "dx-datagrid-pager";
var viewFunction = function(viewModel) {
    return (0, _inferno.createComponentVNode)(2, _placeholder_extender.PlaceholderExtender, {
        type: _footer.FooterPlaceholder,
        order: 1,
        template: function() {
            return (0, _inferno.createComponentVNode)(2, _content.PagerContent, {
                className: DATAGRID_PAGER_CLASS,
                pageSizes: viewModel.allowedPageSizes,
                displayMode: viewModel.props.displayMode,
                infoText: viewModel.props.infoText,
                showInfo: viewModel.props.showInfo,
                showNavigationButtons: viewModel.props.showNavigationButtons,
                showPageSizes: viewModel.props.showPageSizeSelector,
                pageCount: viewModel.pageCount,
                visible: viewModel.props.visible,
                totalCount: viewModel.totalCount,
                pageIndex: viewModel.pageIndex,
                pageIndexChange: viewModel.onPageIndexChange,
                pageSize: "all" === viewModel.pageSize ? 0 : viewModel.pageSize,
                pageSizeChange: viewModel.onPageSizeChange
            })
        }
    })
};
exports.viewFunction = viewFunction;
var PagerProps = Object.defineProperties({
    allowedPageSizes: "auto",
    displayMode: "adaptive",
    showInfo: false,
    showNavigationButtons: false,
    showPageSizeSelector: false,
    visible: true
}, {
    infoText: {
        get: function() {
            return _message.default.format("dxPager-infoText")
        },
        configurable: true,
        enumerable: true
    }
});
exports.PagerProps = PagerProps;
var Pager = function(_InfernoComponent) {
    _inheritsLoose(Pager, _InfernoComponent);

    function Pager(props) {
        var _this;
        _this = _InfernoComponent.call(this, props) || this;
        _this.__getterCache = {};
        _this.state = {
            pageIndex: 0,
            pageSize: 0,
            totalCount: 0,
            pageCount: 0
        };
        _this.subscribeToPagingPluginUpdates = _this.subscribeToPagingPluginUpdates.bind(_assertThisInitialized(_this));
        _this.onPageSizeChange = _this.onPageSizeChange.bind(_assertThisInitialized(_this));
        _this.onPageIndexChange = _this.onPageIndexChange.bind(_assertThisInitialized(_this));
        return _this
    }
    var _proto = Pager.prototype;
    _proto.createEffects = function() {
        return [new _inferno2.InfernoEffect(this.subscribeToPagingPluginUpdates, [this.plugins])]
    };
    _proto.updateEffects = function() {
        var _this$_effects$;
        null === (_this$_effects$ = this._effects[0]) || void 0 === _this$_effects$ ? void 0 : _this$_effects$.update([this.plugins])
    };
    _proto.subscribeToPagingPluginUpdates = function() {
        var _this2 = this;
        this.plugins.watch(_paging.PagingPlugin, (function(prop) {
            _this2.setState((function(__state_argument) {
                return {
                    pageIndex: prop.pageIndex
                }
            }));
            _this2.setState((function(__state_argument) {
                return {
                    pageSize: prop.pageSize
                }
            }));
            _this2.setState((function(__state_argument) {
                return {
                    totalCount: prop.totalCount
                }
            }));
            _this2.setState((function(__state_argument) {
                return {
                    pageCount: prop.pageCount
                }
            }))
        }))
    };
    _proto.onPageSizeChange = function(pageSize) {
        var _this$plugins$getValu;
        var setPageSize = null === (_this$plugins$getValu = this.plugins.getValue(_paging.PagingPlugin)) || void 0 === _this$plugins$getValu ? void 0 : _this$plugins$getValu.setPageSize;
        if (!setPageSize) {
            return
        }
        if (0 === pageSize) {
            setPageSize("all")
        } else {
            setPageSize(pageSize)
        }
    };
    _proto.onPageIndexChange = function(pageIndex) {
        var _this$plugins$getValu2, _this$plugins$getValu3;
        null === (_this$plugins$getValu2 = this.plugins.getValue(_paging.PagingPlugin)) || void 0 === _this$plugins$getValu2 ? void 0 : null === (_this$plugins$getValu3 = _this$plugins$getValu2.setPageIndex) || void 0 === _this$plugins$getValu3 ? void 0 : _this$plugins$getValu3.call(_this$plugins$getValu2, pageIndex)
    };
    _proto.componentWillUpdate = function(nextProps, nextState, context) {
        _InfernoComponent.prototype.componentWillUpdate.call(this);
        if (this.state.pageSize !== nextState.pageSize || this.props.allowedPageSizes !== nextProps.allowedPageSizes) {
            this.__getterCache.allowedPageSizes = void 0
        }
    };
    _proto.render = function() {
        var props = this.props;
        return viewFunction({
            props: _extends({}, props),
            pageIndex: this.state.pageIndex,
            pageSize: this.state.pageSize,
            totalCount: this.state.totalCount,
            pageCount: this.state.pageCount,
            plugins: this.plugins,
            onPageSizeChange: this.onPageSizeChange,
            onPageIndexChange: this.onPageIndexChange,
            allowedPageSizes: this.allowedPageSizes,
            restAttributes: this.restAttributes
        })
    };
    _createClass(Pager, [{
        key: "plugins",
        get: function() {
            if ("PluginsContext" in this.context) {
                return this.context.PluginsContext
            }
            return _context.PluginsContext
        }
    }, {
        key: "allowedPageSizes",
        get: function() {
            var _this3 = this;
            if (void 0 !== this.__getterCache.allowedPageSizes) {
                return this.__getterCache.allowedPageSizes
            }
            return this.__getterCache.allowedPageSizes = function() {
                var pageSize = _this3.state.pageSize;
                if ("auto" === _this3.props.allowedPageSizes) {
                    if ("all" === pageSize) {
                        return []
                    }
                    return [Math.floor(pageSize / 2), pageSize, 2 * pageSize]
                }
                return _this3.props.allowedPageSizes
            }()
        }
    }, {
        key: "restAttributes",
        get: function() {
            var _this$props = this.props,
                restProps = (_this$props.allowedPageSizes, _this$props.displayMode, _this$props.infoText, _this$props.showInfo, _this$props.showNavigationButtons, _this$props.showPageSizeSelector, _this$props.visible, _objectWithoutProperties(_this$props, _excluded));
            return restProps
        }
    }]);
    return Pager
}(_inferno2.InfernoComponent);
exports.Pager = Pager;
Pager.defaultProps = PagerProps;
